@@ -24,9 +24,9 @@ author = "Egemen Imre"
 # Version Info
 # ------------
 # The short X.Y version.
-version = "0.0.7"
+version = "0.1"
 # The full version, including alpha/beta/rc tags.
-release = "0.0.7"
+release = "0.1"
 
 # -- General configuration ---------------------------------------------------
 # By default, highlight as Python 3.
