@@ -247,8 +247,12 @@ class TimeInterval:
         """
         intersection = self._interval.intersection(interval._interval)
 
+        if intersection.empty:
+            # There is absolutely no intersection
+            return False
+
         if _are_times_almost_equal(intersection.upper, intersection.lower):
-            # intersection below tolerance - practically no intersection
+            # intersection below tolerance - practically empty intersection
             return False
         else:
             # see what the underlying function says
@@ -457,7 +461,8 @@ def _create_interval_from_portion(interval, replicate=False):
 
     Returns
     -------
-    New `TimeInterval` instance
+    TimeInterval
+        New `TimeInterval` instance
     """
     return TimeInterval(
         interval.lower,
@@ -502,11 +507,9 @@ class TimeIntervalList:
         Raised if `init_times` and `end_times` objects sizes mismatch.
     """
 
-    def __init__(
-        self, intervals, start_valid=None, end_valid=None, replicate=False,
-    ):
+    def __init__(self, intervals, start_valid=None, end_valid=None, replicate=False):
 
-        self.intervals: list = []
+        self._intervals: list = []
 
         if intervals:
             # if start_times is None, then there is no time interval defined
@@ -515,7 +518,7 @@ class TimeIntervalList:
             p_intervals = self._to_p_intervals(intervals)
 
             # Fill the atomic `TimeInterval` objects using the merged list
-            self.intervals = self._to_time_intervals(p_intervals, replicate)
+            self._intervals = self._to_time_intervals(p_intervals, replicate)
 
         # Init range of validity
         self._valid_interval = self.__init_validity_rng(
@@ -598,17 +601,208 @@ class TimeIntervalList:
             `False` if requested time is outside validity interval.
         """
         # Is time within validity interval?
-        if not self.validity_interval().is_in_interval(time):
+        if not self.valid_interval.is_in_interval(time):
             return False
 
         # Are there any events that contain this time instant?
-        for interval in self.intervals:
+        for interval in self._intervals:
             if interval.is_in_interval(time):
                 return True
 
         # If we are here, then no interval contains the time
         return False
 
+    def is_intersecting(self, interval):
+        """
+        Checks whether the requested interval intersects (or is contained within)
+        the interval list.
+
+        Parameters
+        ----------
+        interval : TimeInterval
+            Time interval to be checked
+
+        Returns
+        -------
+        bool
+            `True` if check interval intersects with the interval list,
+            `False` otherwise
+        """
+        if len(self._intervals) == 0:
+            # No interval present in the list, hence no intersection
+            return False
+
+        # While not very elegant, loop through the interval list to check
+        # for intersections
+        intersect_intervals = [
+            interval_member
+            for interval_member in self.intervals
+            if interval_member.is_intersecting(interval)
+        ]
+
+        if len(intersect_intervals) > 0:
+            return True
+        else:
+            return False
+
+    def intersect(self, interval):
+        """
+        Intersection operator for a time interval and this time interval list.
+
+        Returns a new interval that is the Intersection of the interval and
+        the time interval list, or None if there is no intersection.
+
+        Parameters
+        ----------
+        interval : TimeInterval
+            Time interval to be checked
+
+        Returns
+        -------
+        TimeInterval
+           A new interval that is the Intersection of the interval and
+           the time interval list, or None if there is no intersection.
+
+        """
+        if len(self.intervals) == 0:
+            # No interval present in the list, hence no intersection possible
+            return None
+
+        # While not very elegant, loop through the interval list to check
+        # for intersections
+        intersect_intervals = [
+            interval_member.intersect(interval)
+            for interval_member in self.intervals
+            if interval_member.is_intersecting(interval)
+        ]
+
+        if len(intersect_intervals) > 0:
+            # There can be only a single intersection
+            return intersect_intervals[0]
+        else:
+            # no intersection
+            return None
+
+    def intersect_list(self, interval_list):
+        """
+        Intersection operator for a time interval list and this time interval list.
+
+        Returns a new interval list that is the Intersection of `interval_list` and
+        this time interval list, or None if there is no intersection even in the
+        validity intervals.
+
+        Parameters
+        ----------
+        interval_list : TimeIntervalList
+            Time interval list to be checked
+
+        Returns
+        -------
+        TimeIntervalList
+           A new interval list that is the Intersection of `interval_list` and
+           this time interval list, or None if there is no intersection.
+
+        """
+        if not self.valid_interval.is_intersecting(interval_list.valid_interval):
+            # Validity intervals do not intersect, hence no intersection possible
+            return None
+
+        common_valid_interval = self.valid_interval.intersect(
+            interval_list.valid_interval
+        )
+
+        # Compute the portion intervals
+        p_self_intervals = TimeIntervalList._to_p_intervals(self.intervals)
+        p_other_intervals = TimeIntervalList._to_p_intervals(interval_list.intervals)
+
+        # Do the Intersection
+        p_final = p_self_intervals.intersection(p_other_intervals)
+
+        return TimeIntervalList(
+            self._to_time_intervals(p_final), start_valid=common_valid_interval
+        )
+
+    def union(self, interval):
+        """
+        Union operator for a time interval and this time interval list.
+
+        Returns a new interval that is the Union of the interval and
+        the time interval list, or None if there is no intersection.
+
+        Parameters
+        ----------
+        interval : TimeInterval
+            Time interval to be checked
+
+        Returns
+        -------
+        TimeInterval
+           A new interval that is the Union of the interval and
+           the time interval list, or None if there is no intersection.
+
+        """
+        if len(self.intervals) == 0:
+            # No interval present in the list, hence no intersection possible
+            return None
+
+        # While not very elegant, loop through the interval list to check
+        # for intersections
+        union_intervals = [
+            interval_member.union(interval)
+            for interval_member in self.intervals
+            if interval_member.is_intersecting(interval)
+        ]
+
+        if len(union_intervals) > 0:
+            # There can be only a single intersection
+            return union_intervals[0]
+        else:
+            # no intersection
+            return None
+
+    def union_list(self, interval_list):
+        """
+        Union operator for a time interval list and this time interval list.
+
+        Returns a new interval list that is the Union of `interval_list` and
+        this time interval list, or None if there is no intersection even in the
+        validity intervals.
+
+        Parameters
+        ----------
+        interval_list : TimeIntervalList
+            Time interval list to be checked
+
+        Returns
+        -------
+        TimeIntervalList
+           A new interval list that is the Union of `interval_list` and
+           this time interval list, or None if there is no intersection.
+
+        """
+        if not self.valid_interval.is_intersecting(interval_list.valid_interval):
+            # Validity intervals do not intersect, hence no intersection possible
+            return None
+
+        common_valid_interval = self.valid_interval.intersect(
+            interval_list.valid_interval
+        )
+
+        # Compute the portion intervals
+        p_self_intervals = TimeIntervalList._to_p_intervals(self.intervals)
+        p_other_intervals = TimeIntervalList._to_p_intervals(interval_list.intervals)
+
+        # Do the Union
+        p_union = p_self_intervals.union(p_other_intervals)
+
+        # Reduce union to the common interval
+        p_common = common_valid_interval.p_interval
+        p_final = p_union.intersection(p_common)
+
+        return TimeIntervalList(
+            self._to_time_intervals(p_final), start_valid=common_valid_interval
+        )
+
     def invert(self, replicate=False):
         """
         Creates an *inverted* (or complement) copy of this time interval list, while
@@ -630,13 +824,13 @@ class TimeIntervalList:
         intervals are inverted.
         """
         # Convert `TimeInterval` list to `Interval`
-        p_interval = self._to_p_intervals(self.intervals)
+        p_interval = self._to_p_intervals(self._intervals)
 
         # Do the inversion
         p_int_inverted = ~p_interval
 
         # Fix the ends as necessary - no inf allowed
-        p_validity = self._to_p_intervals(self.validity_interval())
+        p_validity = self._to_p_intervals(self.valid_interval)
         p_int_inverted = p_int_inverted.intersection(p_validity)
 
         # Generate the `TimeInterval` list
@@ -644,7 +838,7 @@ class TimeIntervalList:
 
         # Create the `TimeIntervalList` object
         return TimeIntervalList(
-            intervals, start_valid=self.validity_interval(), replicate=replicate
+            intervals, start_valid=self.valid_interval, replicate=replicate
         )
 
     def get_interval(self, index):
@@ -667,19 +861,22 @@ class TimeIntervalList:
             Requested index is out of bounds
 
         """
-        return self.intervals[index]
+        return self._intervals[index]
 
-    def validity_interval(self) -> TimeInterval:
+    @property
+    def valid_interval(self) -> TimeInterval:
         """
         Gets the time interval of validity for the `TimeIntervalList`.
-
-        Returns
-        -------
-        `TimeInterval` of interval of validity
-
         """
         return self._valid_interval
 
+    @property
+    def intervals(self):
+        """
+        Gets the time intervals within this `TimeIntervalList`.
+        """
+        return self._intervals
+
     @staticmethod
     def _to_time_intervals(p_intervals, replicate=False):
         """
@@ -695,7 +892,8 @@ class TimeIntervalList:
 
         Returns
         -------
-        `TimeInterval` object with the list of time intervals
+        list[TimeInterval]
+            `TimeInterval` object with the list of time intervals
         """
         intervals: list = []
 
@@ -737,9 +935,9 @@ class TimeIntervalList:
 
     def __str__(self):
         txt = ""
-        if self.intervals:
+        if self._intervals:
             # List not empty
-            for interval in self.intervals:
+            for interval in self._intervals:
                 txt += str(interval) + "\n"
         else:
             txt = "Time interval list is empty."
